@@ -3,12 +3,7 @@ import pytest
 
 from ninja_extra import api_controller, route
 from ninja_extra.controllers import AsyncRouteFunction, RouteFunction
-from ninja_extra.operation import (
-    AsyncControllerOperation,
-    AsyncOperation,
-    ControllerOperation,
-    Operation,
-)
+from ninja_extra.operation import AsyncOperation, Operation
 from ninja_extra.testing import TestAsyncClient, TestClient
 
 from .utils import AsyncFakeAuth, FakeAuth, mock_log_call, mock_signal_call
