@@ -4,24 +4,14 @@ import django
 import pytest
 from django.contrib.auth.models import AnonymousUser, User
 from ninja import Schema
+from ninja.constants import NOT_SET
 
-from ninja_extra import (
-    api_controller,
-    http_delete,
-    http_generic,
-    http_get,
-    http_patch,
-    http_post,
-    http_put,
-    permissions,
-    route,
-)
+from ninja_extra import api_controller, permissions, route
 from ninja_extra.controllers import (
     AsyncRouteFunction,
     Detail,
     Id,
     Ok,
-    Route,
     RouteFunction,
     RouteInvalidParameterException,
 )
@@ -30,6 +20,7 @@ from ninja_extra.controllers.route.context import RouteContext
 from ninja_extra.exceptions import PermissionDenied
 from ninja_extra.permissions import AllowAny
 
+from .schemas import UserSchema
 from .utils import FakeAuth
 
 anonymous_request = Mock()
@@ -42,45 +33,49 @@ anonymous_request.user = AnonymousUser()
     permissions=[permissions.IsAuthenticated & permissions.IsAdminUser],
 )
 class PermissionController:
-    @http_post("/example_post", auth=None)
+    @route.post("/example_post", auth=None)
     def example(self):
         return {"message": "OK"}
 
-    @http_get("/example_get", auth=None, permissions=[permissions.AllowAny])
+    @route.get("/example_get", auth=None, permissions=[permissions.AllowAny])
     def example_allow_any(self):
         return {"message": "OK"}
 
 
 @api_controller
 class SomeTestController:
-    @http_get("/example")
+    @route.get("/example")
     def example(self):
         pass
 
-    @http_post("/example")
+    @route.post("/example")
     def example_post(self):
         pass
 
-    @http_patch("/example/{ex_id}")
+    @route.patch("/example/{ex_id}")
     def example_patch(self, ex_id: str):
         pass
 
-    @http_patch("/example/{ex_id}")
+    @route.patch("/example/{ex_id}")
     def example_put(self, ex_id: str):
         pass
 
-    @http_delete("/example/{ex_id}")
+    @route.delete("/example/{ex_id}")
     def example_delete(self, ex_id: str):
         pass
 
-    @http_generic("/example/list", methods=["POST", "GET"])
+    @route.generic("/example/list", methods=["POST", "GET"])
     def example_list_create(self, ex_id: str):
         pass
 
-    @http_post("/example/operation-id", operation_id="example_post_operation_id")
+    @route.post("/example/operation-id", operation_id="example_post_operation_id")
     def example_post_operation_id(self):
         pass
 
+    @route.get("/example/return-response-as-schema")
+    def function_return_as_response_schema(self) -> UserSchema:
+        pass
+
 
 class TestControllerRoute:
     @pytest.mark.parametrize(
@@ -124,6 +119,14 @@ class TestControllerRoute:
             == SomeTestController.example
         )
 
+    def test_controller_route_should_use_userschema_as_response(self):
+        route_function: RouteFunction = SomeTestController.example
+        assert route_function.route.route_params.response == NOT_SET
+        route_function: RouteFunction = (
+            SomeTestController.function_return_as_response_schema
+        )
+        assert route_function.route.route_params.response == UserSchema
+
     def test_route_generic_invalid_parameters(self):
         with pytest.raises(RouteInvalidParameterException) as ex:
 
@@ -205,15 +208,18 @@ class TestControllerRoute:
         ],
     )
     def test_route_generates_required_route_definitions(self, func, methods, kwargs):
+        def view_func(request):
+            pass
+
         route_method = getattr(route, func)
-        route_instance: Route = (
+        route_instance: RouteFunction = (
             route_method("/", methods=methods, **kwargs)
             if func == "generic"
             else route_method("/", **kwargs)
-        )
-        assert route_instance.route_params.methods == methods
+        )(view_func)
+        assert route_instance.route.route_params.methods == methods
         for k, v in kwargs.items():
-            assert getattr(route_instance.route_params, k) == v
+            assert getattr(route_instance.route.route_params, k) == v
 
 
 @pytest.mark.skipif(django.VERSION < (3, 1), reason="requires django 3.1 or higher")
